aboutsummaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorMattias Andrée <maandree@operamail.com>2014-12-08 19:34:26 +0100
committerMattias Andrée <maandree@operamail.com>2014-12-08 19:34:26 +0100
commit3e07c8b1657e28f19072b430936e88be040fb319 (patch)
tree079b9c8b4669873578cce9eccd79d53c89467a1f /src
parentm + make sure we never lose errno (diff)
downloadmds-3e07c8b1657e28f19072b430936e88be040fb319.tar.gz
mds-3e07c8b1657e28f19072b430936e88be040fb319.tar.bz2
mds-3e07c8b1657e28f19072b430936e88be040fb319.tar.xz
rename pfail to fail
Signed-off-by: Mattias Andrée <maandree@operamail.com>
Diffstat (limited to 'src')
-rw-r--r--src/libmdsserver/client-list.c2
-rw-r--r--src/libmdsserver/linked-list.c4
-rw-r--r--src/libmdsserver/macros.h4
-rw-r--r--src/libmdsserver/mds-message.c2
-rw-r--r--src/libmdsserver/util.c2
-rw-r--r--src/mds-base.c12
-rw-r--r--src/mds-clipboard.c16
-rw-r--r--src/mds-echo.c4
-rw-r--r--src/mds-kbdc/callables.c2
-rw-r--r--src/mds-kbdc/compile-layout.c26
-rw-r--r--src/mds-kbdc/eliminate-dead-code.c4
-rw-r--r--src/mds-kbdc/include-stack.c6
-rw-r--r--src/mds-kbdc/make-tree.c48
-rw-r--r--src/mds-kbdc/mds-kbdc.c2
-rw-r--r--src/mds-kbdc/parsed.c2
-rw-r--r--src/mds-kbdc/paths.c6
-rw-r--r--src/mds-kbdc/process-includes.c6
-rw-r--r--src/mds-kbdc/raw-data.c10
-rw-r--r--src/mds-kbdc/simplify-tree.c14
-rw-r--r--src/mds-kbdc/tree.c2
-rw-r--r--src/mds-kbdc/validate-tree.c22
-rw-r--r--src/mds-kkbd.c8
-rw-r--r--src/mds-registry/mds-registry.c6
-rw-r--r--src/mds-registry/reexec.c2
-rw-r--r--src/mds-registry/registry.c6
-rw-r--r--src/mds-registry/slave.c6
-rw-r--r--src/mds-respawn.c6
-rw-r--r--src/mds-server/client.c2
-rw-r--r--src/mds-server/mds-server.c10
-rw-r--r--src/mds-server/receiving.c10
-rw-r--r--src/mds-server/slavery.c4
-rw-r--r--src/mds-vt.c6
-rw-r--r--src/mds.c8
33 files changed, 135 insertions, 135 deletions
diff --git a/src/libmdsserver/client-list.c b/src/libmdsserver/client-list.c
index 1bcaa72..ff3ffe2 100644
--- a/src/libmdsserver/client-list.c
+++ b/src/libmdsserver/client-list.c
@@ -116,7 +116,7 @@ int client_list_clone(const client_list_t* restrict this, client_list_t* restric
return 0;
- pfail:
+ fail:
saved_errno = errno;
free(new_clients);
return errno = saved_errno, -1;
diff --git a/src/libmdsserver/linked-list.c b/src/libmdsserver/linked-list.c
index d17ba8b..7756d90 100644
--- a/src/libmdsserver/linked-list.c
+++ b/src/libmdsserver/linked-list.c
@@ -145,7 +145,7 @@ int linked_list_clone(const linked_list_t* restrict this, linked_list_t* restric
return 0;
- pfail:
+ fail:
saved_errno = errno;
free(new_values);
free(new_next);
@@ -221,7 +221,7 @@ int linked_list_pack(linked_list_t* restrict this)
return 0;
- pfail:
+ fail:
saved_errno = errno;
free(vals);
free(new_next);
diff --git a/src/libmdsserver/mds-message.c b/src/libmdsserver/mds-message.c
index d616355..4075f57 100644
--- a/src/libmdsserver/mds-message.c
+++ b/src/libmdsserver/mds-message.c
@@ -545,7 +545,7 @@ int mds_message_unmarshal(mds_message_t* restrict this, char* restrict data)
return 0;
- pfail:
+ fail:
return -1;
}
diff --git a/src/libmdsserver/util.c b/src/libmdsserver/util.c
index 70faf3d..2e72229 100644
--- a/src/libmdsserver/util.c
+++ b/src/libmdsserver/util.c
@@ -369,7 +369,7 @@ pid_t uninterruptable_waitpid(pid_t pid, int* restrict status, int options)
/* Don't let the CPU catch fire! */
errno = EINTR;
}
- pfail:
+ fail:
return rc;
}
diff --git a/src/mds-base.c b/src/mds-base.c
index f8fca62..df0e680 100644
--- a/src/mds-base.c
+++ b/src/mds-base.c
@@ -189,7 +189,7 @@ int __attribute__((weak)) connect_to_display(void)
return 0;
- pfail:
+ fail:
xperror(*argv);
if (socket_fd >= 0)
close(socket_fd);
@@ -417,7 +417,7 @@ static int base_unmarshal(void)
fail_if (reexec_failure_recover());
return 0;
- pfail:
+ fail:
xperror(*argv);
return 1;
}
@@ -460,7 +460,7 @@ static int base_marshal(int reexec_fd)
free(state_buf);
return 0;
- pfail:
+ fail:
xperror(*argv);
free(state_buf);
return 1;
@@ -490,7 +490,7 @@ static void perform_reexec(void)
/* Re-exec the server. */
reexec_server(argc, argv, is_reexec);
- pfail:
+ fail:
xperror(*argv);
if (reexec_fd >= 0)
{
@@ -578,7 +578,7 @@ int main(int argc_, char** argv_)
return 0;
- pfail:
+ fail:
xperror(*argv);
if (socket_fd >= 0)
close(socket_fd);
@@ -638,7 +638,7 @@ int trap_signals(void)
{ fail_if (xsigaction(SIGDANGER, received_danger) < 0); }
return 0;
- pfail:
+ fail:
xperror(*argv);
return 1;
}
diff --git a/src/mds-clipboard.c b/src/mds-clipboard.c
index a2a43eb..2488179 100644
--- a/src/mds-clipboard.c
+++ b/src/mds-clipboard.c
@@ -138,7 +138,7 @@ int initialise_server(void)
return 0;
- pfail:
+ fail:
xperror(*argv);
mds_message_destroy(&received);
while (--i >= 0)
@@ -305,7 +305,7 @@ int unmarshal_server(char* state_buf)
}
return 0;
- pfail:
+ fail:
xperror(*argv);
mds_message_destroy(&received);
for (i = 0; i < CLIPBOARD_LEVELS; i++)
@@ -374,7 +374,7 @@ int master_loop(void)
rc = 0;
goto done;
- pfail:
+ fail:
xperror(*argv);
done:
if (!rc && reexecing)
@@ -636,7 +636,7 @@ static int clipboard_purge(int level, const char* client_id)
}
return 0;
- pfail:
+ fail:
xperror(*argv);
return -1;
}
@@ -727,7 +727,7 @@ int clipboard_add(int level, const char* time_to_live, const char* recv_client_i
clipboard[level][0] = new_clip;
return 0;
- pfail:
+ fail:
xperror(*argv);
return -1;
}
@@ -801,7 +801,7 @@ int clipboard_read(int level, size_t index, const char* recv_client_id, const ch
free(message);
return 0;
- pfail:
+ fail:
xperror(*argv);
return -1;
}
@@ -859,7 +859,7 @@ int clipboard_set_size(int level, size_t size)
}
return 0;
- pfail:
+ fail:
xperror(*argv);
return -1;
}
@@ -904,7 +904,7 @@ int clipboard_get_size(int level, const char* recv_client_id, const char* recv_m
free(message);
return 0;
- pfail:
+ fail:
xperror(*argv);
free(message);
return -1;
diff --git a/src/mds-echo.c b/src/mds-echo.c
index 4cbaabb..caefecd 100644
--- a/src/mds-echo.c
+++ b/src/mds-echo.c
@@ -112,7 +112,7 @@ int initialise_server(void)
fail_if (mds_message_initialise(&received));
return 0;
- pfail:
+ fail:
xperror(*argv);
mds_message_destroy(&received);
return 1;
@@ -246,7 +246,7 @@ int master_loop(void)
rc = 0;
goto done;
- pfail:
+ fail:
xperror(*argv);
done:
if (rc || !reexecing)
diff --git a/src/mds-kbdc/callables.c b/src/mds-kbdc/callables.c
index 10eddcc..4c984c1 100644
--- a/src/mds-kbdc/callables.c
+++ b/src/mds-kbdc/callables.c
@@ -142,7 +142,7 @@ int callables_set(const char* restrict name, size_t arg_count, mds_kbdc_tree_t*
list_ptr++;
return 0;
- pfail:
+ fail:
saved_errno = errno;
free(dupname);
free(new_names);
diff --git a/src/mds-kbdc/compile-layout.c b/src/mds-kbdc/compile-layout.c
index 9441802..ccf647c 100644
--- a/src/mds-kbdc/compile-layout.c
+++ b/src/mds-kbdc/compile-layout.c
@@ -58,7 +58,7 @@
/**
* Beginning of failure clause
*/
-#define FAIL_BEGIN pfail: saved_errno = errno
+#define FAIL_BEGIN fail: saved_errno = errno
/**
* End of failure clause
@@ -247,7 +247,7 @@ static int check_set_3_get_2_call(mds_kbdc_tree_t* restrict tree, int is_set, co
FUN_ERROR(tree, ERROR, "‘\\%zu’ does not hold %zu elements", (size_t)*variable_arg, (size_t)*index_arg);/* TODO test */
return 0;
- pfail:
+ fail:
return -1;
#undef FUN_ERROR
#undef F
@@ -470,7 +470,7 @@ static char32_t* parse_function_call(mds_kbdc_tree_t* restrict tree, const char*
*rc = -1;
goto done;
- pfail:
+ fail:
saved_errno = errno;
free(rc);
if (old_arguments)
@@ -586,7 +586,7 @@ static void check_function_call(const mds_kbdc_tree_t* restrict tree, const char
error->end = lineoff + (size_t)(*end - raw);
return;
- pfail:
+ fail:
*rc |= -1;
}
@@ -706,7 +706,7 @@ static char32_t* parse_escape(mds_kbdc_tree_t* restrict tree, const char* restri
*escape = 0;
*end = raw;
return rc;
- pfail:
+ fail:
saved_errno = errno;
free(rc);
return errno = saved_errno, NULL;
@@ -838,7 +838,7 @@ static char32_t* parse_quoted_string(mds_kbdc_tree_t* restrict tree, const char*
free(buf);
return rc;
- pfail:
+ fail:
saved_errno = errno;
free(subrc);
free(old_rc);
@@ -890,7 +890,7 @@ static char32_t* parse_unquoted_string(mds_kbdc_tree_t* restrict tree, const cha
fail_if (rc = malloc(2 * sizeof(char32_t)), rc == NULL);
return rc[0] = buf, rc[1] = -1, rc;
- pfail:
+ fail:
return NULL;
#undef CHAR_ERROR
#undef R
@@ -1026,7 +1026,7 @@ static char32_t* parse_keys(mds_kbdc_tree_t* restrict tree, const char* restrict
free(buf);
return last_value_statement = old_last_value_statement, rc;
- pfail:
+ fail:
saved_errno = errno;
free(subrc);
free(old_rc);
@@ -1079,7 +1079,7 @@ static size_t parse_variable(mds_kbdc_tree_t* restrict tree, const char* restric
if (strlen(dotless + 1) != (size_t)snprintf(NULL, 0, "%zu", var))
return errno = ERANGE, (size_t)0;
return var;
- pfail:
+ fail:
return 0;
bad:
@@ -1224,7 +1224,7 @@ static int get_macro(mds_kbdc_tree_macro_call_t* restrict macro_call,
*macro = NULL;
return 0;
- pfail:
+ fail:
return -1;
}
@@ -1848,7 +1848,7 @@ static int check_name_suffix(struct mds_kbdc_tree_callable* restrict tree)
}
return 0;
- pfail:
+ fail:
return -1;
name_error:
error->start = tree->loc_end;
@@ -2187,7 +2187,7 @@ static int evaluate_element(mds_kbdc_tree_t* restrict node)
}
return bad;
- pfail:
+ fail:
return -1;
}
@@ -2260,7 +2260,7 @@ static int check_nonnul(mds_kbdc_tree_t* restrict tree)
tree = tree->next;
goto again;
- pfail:
+ fail:
return -1;
}
diff --git a/src/mds-kbdc/eliminate-dead-code.c b/src/mds-kbdc/eliminate-dead-code.c
index 0881b20..4916fa4 100644
--- a/src/mds-kbdc/eliminate-dead-code.c
+++ b/src/mds-kbdc/eliminate-dead-code.c
@@ -105,7 +105,7 @@ static int eliminate_if(mds_kbdc_tree_if_t* restrict tree)
if (elimination > elimination_level)
elimination = elimination_level;
return 0;
- pfail:
+ fail:
return -1;
}
@@ -156,7 +156,7 @@ static int eliminate_subtree(mds_kbdc_tree_t* restrict tree)
tree = tree->next;
goto again;
- pfail:
+ fail:
return -1;
#undef E
#undef e
diff --git a/src/mds-kbdc/include-stack.c b/src/mds-kbdc/include-stack.c
index d86374e..bec1425 100644
--- a/src/mds-kbdc/include-stack.c
+++ b/src/mds-kbdc/include-stack.c
@@ -85,7 +85,7 @@ int mds_kbdc_include_stack_dump(size_t ptr)
result->pathname = old_pathname;
result->source_code = old_source_code;
return 0;
- pfail:
+ fail:
result->pathname = old_pathname;
result->source_code = old_source_code;
return -1;
@@ -149,7 +149,7 @@ int mds_kbdc_include_stack_push(const mds_kbdc_tree_include_t* restrict tree, vo
latest_save = NULL;
return 0;
- pfail:
+ fail:
saved_errno = errno;
free(old);
return errno = saved_errno, -1;
@@ -205,7 +205,7 @@ mds_kbdc_include_stack_t* mds_kbdc_include_stack_save(void)
memcpy(latest_save->stack, includes, latest_save->ptr * sizeof(const mds_kbdc_tree_include_t*));
return latest_save;
- pfail:
+ fail:
saved_errno = errno;
free(latest_save->stack);
latest_save = NULL;
diff --git a/src/mds-kbdc/make-tree.c b/src/mds-kbdc/make-tree.c
index bb9d59e..8a7bb1e 100644
--- a/src/mds-kbdc/make-tree.c
+++ b/src/mds-kbdc/make-tree.c
@@ -459,7 +459,7 @@ static int get_pathname(const char* restrict filename)
}
return 1;
- pfail:
+ fail:
saved_errno = errno;
free(cwd);
return errno = saved_errno, -1;
@@ -488,7 +488,7 @@ static int allocate_stacks(void)
fail_if (xmalloc(tree_stack, line_n + max_line_length + 1, mds_kbdc_tree_t**));
return 0;
- pfail:
+ fail:
return -1;
}
@@ -504,7 +504,7 @@ static int read_source_code(void)
fail_if (read_source_lines(result->pathname, result->source_code) < 0);
return 0;
- pfail:
+ fail:
return -1;
}
@@ -545,7 +545,7 @@ static int check_for_premature_end_of_file(void)
}
return 0;
- pfail:
+ fail:
return -1;
}
@@ -565,7 +565,7 @@ static int check_whether_file_is_empty(void)
NEW_ERROR(0, WARNING, "file is empty");
return 0;
- pfail:
+ fail:
return -1;
}
@@ -592,7 +592,7 @@ static int no_parameters(const char* restrict keyword)
}
return 0;
- pfail:
+ fail:
return -1;
}
@@ -653,7 +653,7 @@ static int names_1(char** restrict var)
}
return 0;
- pfail:
+ fail:
return -1;
}
@@ -704,7 +704,7 @@ static int chars(char** restrict var)
}
return 0;
- pfail:
+ fail:
return -1;
}
@@ -731,7 +731,7 @@ static int quotes(void)
line = line_;
return 0;
- pfail:
+ fail:
return -1;
}
@@ -756,7 +756,7 @@ static int have_more_parameters(void)
return 0;
}
return 1;
- pfail:
+ fail:
return -1;
}
@@ -789,7 +789,7 @@ static int test_for_keyword(const char* restrict keyword)
NEW_ERROR(1, ERROR, "expecting keyword ‘%s’", keyword);
return 0;
- pfail:
+ fail:
return -1;
}
@@ -844,7 +844,7 @@ static int keys(mds_kbdc_tree_t** restrict var)
line = end;
return 0;
- pfail:
+ fail:
return -1;
}
@@ -889,7 +889,7 @@ static int pure_keys(char** restrict var)
end = arg_end, line = end;
return 0;
- pfail:
+ fail:
return -1;
}
@@ -959,7 +959,7 @@ static int sequence(int mapseq, size_t stack_orig)
}
return 0;
- pfail:
+ fail:
return -1;
}
@@ -984,7 +984,7 @@ static int sequence_fully_popped(size_t stack_orig)
}
return 0;
- pfail:
+ fail:
return -1;
}
@@ -1052,7 +1052,7 @@ static int parse_else(void)
}
return 0;
- pfail:
+ fail:
return -1;
}
@@ -1074,7 +1074,7 @@ static int parse_for(void)
BRANCH("for");
return 0;
- pfail:
+ fail:
return -1;
}
@@ -1128,7 +1128,7 @@ static int parse_let(void)
}
return 0;
- pfail:
+ fail:
return -1;
}
@@ -1159,7 +1159,7 @@ static int parse_end(void)
NEXT;
return 0;
- pfail:
+ fail:
return -1;
}
@@ -1218,7 +1218,7 @@ static int parse_map(void)
NEW_ERROR(1, ERROR, "too many parameters");
return 0;
- pfail:
+ fail:
return -1;
}
@@ -1283,7 +1283,7 @@ static int parse_macro_call(void)
NEW_ERROR(1, ERROR, "invalid syntax ‘%s’", line);
return 0;
- pfail:
+ fail:
return -1;
}
@@ -1323,7 +1323,7 @@ static int parse_array_elements(void)
}
}
- pfail:
+ fail:
return -1;
}
@@ -1375,7 +1375,7 @@ static int parse_line(void)
*end = prev_end_char;
return 0;
- pfail:
+ fail:
return -1;
#undef p
}
@@ -1442,7 +1442,7 @@ int parse_to_tree(const char* restrict filename, mds_kbdc_parsed_t* restrict res
free(tree_stack);
return 0;
- pfail:
+ fail:
saved_errno = errno;
free(keyword_stack);
free(tree_stack);
diff --git a/src/mds-kbdc/mds-kbdc.c b/src/mds-kbdc/mds-kbdc.c
index ed690a7..33b97b2 100644
--- a/src/mds-kbdc/mds-kbdc.c
+++ b/src/mds-kbdc/mds-kbdc.c
@@ -85,7 +85,7 @@ int main(int argc_, char** argv_)
mds_kbdc_parsed_destroy(&result);
return fatal;
- pfail:
+ fail:
xperror(*argv);
mds_kbdc_parsed_destroy(&result);
return 1;
diff --git a/src/mds-kbdc/parsed.c b/src/mds-kbdc/parsed.c
index a049b9c..8ab483b 100644
--- a/src/mds-kbdc/parsed.c
+++ b/src/mds-kbdc/parsed.c
@@ -150,7 +150,7 @@ mds_kbdc_parse_error_t* mds_kbdc_parsed_new_error(mds_kbdc_parsed_t* restrict th
}
return error;
- pfail:
+ fail:
saved_errno = errno;
free(error);
this->errors_ptr = old_errors_ptr;
diff --git a/src/mds-kbdc/paths.c b/src/mds-kbdc/paths.c
index 552aaae..a14681e 100644
--- a/src/mds-kbdc/paths.c
+++ b/src/mds-kbdc/paths.c
@@ -50,7 +50,7 @@ char* curpath(void)
}
return cwd;
- pfail:
+ fail:
saved_errno = errno;
free(old);
free(cwd);
@@ -104,7 +104,7 @@ char* abspath(const char* path)
free(cwd);
return buf;
- pfail:
+ fail:
saved_errno = errno;
free(cwd);
errno = saved_errno;
@@ -154,7 +154,7 @@ char* relpath(const char* path, const char* base)
free(abs);
free(absbase);
return buf;
- pfail:
+ fail:
saved_errno = errno;
free(abs);
free(absbase);
diff --git a/src/mds-kbdc/process-includes.c b/src/mds-kbdc/process-includes.c
index 18d995f..57e0502 100644
--- a/src/mds-kbdc/process-includes.c
+++ b/src/mds-kbdc/process-includes.c
@@ -135,7 +135,7 @@ static int transfer_errors(mds_kbdc_parsed_t* restrict subresult, mds_kbdc_tree_
free(errors);
return 0;
- pfail:
+ fail:
saved_errno = errno;
while (errors_ptr--)
mds_kbdc_parse_error_free(errors[errors_ptr]);
@@ -223,7 +223,7 @@ static int process_include(mds_kbdc_tree_include_t* restrict tree)
mds_kbdc_parsed_destroy(&subresult);
return 0;
- pfail:
+ fail:
saved_errno = errno;
free(dirname);
free(cwd);
@@ -309,7 +309,7 @@ int process_includes(mds_kbdc_parsed_t* restrict result_)
free(included), included_size = 0;
return errno = saved_errno, r;
- pfail:
+ fail:
return -1;
}
diff --git a/src/mds-kbdc/raw-data.c b/src/mds-kbdc/raw-data.c
index c47269a..359abe8 100644
--- a/src/mds-kbdc/raw-data.c
+++ b/src/mds-kbdc/raw-data.c
@@ -145,7 +145,7 @@ static char* read_file(const char* restrict pathname, size_t* restrict size)
*size = buf_ptr;
return content;
- pfail:
+ fail:
xperror(*argv);
free(old);
free(content);
@@ -325,7 +325,7 @@ static char** line_split(char* content, size_t length)
return lines;
- pfail:
+ fail:
xperror(*argv);
return NULL;
}
@@ -370,7 +370,7 @@ static int expand(char** restrict content, size_t* restrict content_size)
while (++col % 8);
return 0;
- pfail:
+ fail:
return -1;
}
@@ -429,7 +429,7 @@ int read_source_lines(const char* restrict pathname, mds_kbdc_source_code_t* res
source_code->line_count = line_count;
return 0;
- pfail:
+ fail:
xperror(*argv);
free(old);
free(content);
@@ -519,7 +519,7 @@ char* parse_raw_string(const char* restrict string)
*p = '\0';
return rc;
- pfail:
+ fail:
free(rc);
return NULL;
#undef r
diff --git a/src/mds-kbdc/simplify-tree.c b/src/mds-kbdc/simplify-tree.c
index 713a898..c46649e 100644
--- a/src/mds-kbdc/simplify-tree.c
+++ b/src/mds-kbdc/simplify-tree.c
@@ -321,7 +321,7 @@ static int simplify_macro_call(mds_kbdc_tree_macro_call_t* restrict tree)
*/
return 0;
- pfail:
+ fail:
saved_errno = errno;
mds_kbdc_tree_free(dup_arguments);
return errno = saved_errno, -1;
@@ -352,7 +352,7 @@ static int check_value_statement_before_simplification(mds_kbdc_tree_map_t* rest
fail_if (simplify(tree->sequence));
goto again;
- pfail:
+ fail:
return -1;
}
@@ -374,7 +374,7 @@ static int check_value_statement_after_simplification(mds_kbdc_tree_map_t* restr
NEW_ERROR(tree->sequence, ERROR, "bad value type");
return 0;
- pfail:
+ fail:
return -1;
}
@@ -530,7 +530,7 @@ static int simplify_map(mds_kbdc_tree_map_t* restrict tree)
*/
return 0;
- pfail:
+ fail:
saved_errno = errno;
mds_kbdc_tree_free(dup_sequence);
return errno = saved_errno, -1;
@@ -603,7 +603,7 @@ static int simplify_alternation(mds_kbdc_tree_alternation_t* restrict tree)
}
return 0;
- pfail:
+ fail:
return -1;
}
@@ -678,7 +678,7 @@ static mds_kbdc_tree_t* create_permutations(mds_kbdc_tree_t* elements)
return first;
- pfail:
+ fail:
saved_errno = errno;
mds_kbdc_tree_free(first);
mds_kbdc_tree_free(subperms);
@@ -790,7 +790,7 @@ static int simplify_unordered(mds_kbdc_tree_unordered_t* restrict tree)
mds_kbdc_tree_free(arguments);
return 0;
- pfail:
+ fail:
return -1;
}
diff --git a/src/mds-kbdc/tree.c b/src/mds-kbdc/tree.c
index dd0eb68..ac9de2b 100644
--- a/src/mds-kbdc/tree.c
+++ b/src/mds-kbdc/tree.c
@@ -331,7 +331,7 @@ mds_kbdc_tree_t* mds_kbdc_tree_dup(const mds_kbdc_tree_t* restrict this)
node = &(n->next);
goto again;
- pfail:
+ fail:
saved_errno = errno;
mds_kbdc_tree_free(rc);
return errno = saved_errno, NULL;
diff --git a/src/mds-kbdc/validate-tree.c b/src/mds-kbdc/validate-tree.c
index ed96343..eeb5735 100644
--- a/src/mds-kbdc/validate-tree.c
+++ b/src/mds-kbdc/validate-tree.c
@@ -151,7 +151,7 @@ static int validate_function(mds_kbdc_tree_function_t* restrict tree)
def_includes_ptr = includes_ptr;
r = validate_subtree(tree->inner);
return function = NULL, r;
- pfail:
+ fail:
return -1;
}
@@ -193,7 +193,7 @@ static int validate_macro(mds_kbdc_tree_macro_t* restrict tree)
def_includes_ptr = includes_ptr;
r = validate_subtree(tree->inner);
return macro = NULL, r;
- pfail:
+ fail:
return -1;
}
@@ -235,7 +235,7 @@ static int validate_information(mds_kbdc_tree_information_t* restrict tree)
def_includes_ptr = includes_ptr;
r = validate_subtree(tree->inner);
return information = NULL, r;
- pfail:
+ fail:
return -1;
}
@@ -277,7 +277,7 @@ static int validate_assumption(mds_kbdc_tree_assumption_t* restrict tree)
def_includes_ptr = includes_ptr;
r = validate_subtree(tree->inner);
return assumption = NULL, r;
- pfail:
+ fail:
return -1;
}
@@ -305,7 +305,7 @@ static int validate_map(mds_kbdc_tree_map_t* restrict tree)
else if (function)
NEW_ERROR(tree, includes_ptr, ERROR, "mapping-statement inside function definition");
return 0;
- pfail:
+ fail:
return -1;
}
@@ -325,7 +325,7 @@ static int validate_macro_call(mds_kbdc_tree_macro_call_t* restrict tree)
else if (function)
NEW_ERROR(tree, includes_ptr, ERROR, "macro call inside function definition");
return 0;
- pfail:
+ fail:
return -1;
}
@@ -369,7 +369,7 @@ static int validate_return(mds_kbdc_tree_return_t* restrict tree)
if ((function == NULL) && (macro == NULL))
NEW_ERROR(tree, includes_ptr, ERROR, "‘return’ outside function and macro definition");
return 0;
- pfail:
+ fail:
return -1;
}
@@ -385,7 +385,7 @@ static int validate_break(mds_kbdc_tree_break_t* restrict tree)
if (fors == 0)
NEW_ERROR(tree, includes_ptr, ERROR, "‘break’ outside ‘for’");
return 0;
- pfail:
+ fail:
return -1;
}
@@ -401,7 +401,7 @@ static int validate_continue(mds_kbdc_tree_continue_t* restrict tree)
if (fors == 0)
NEW_ERROR(tree, includes_ptr, ERROR, "‘continue’ outside ‘for’");
return 0;
- pfail:
+ fail:
return -1;
}
@@ -417,7 +417,7 @@ static int validate_assumption_data(mds_kbdc_tree_t* restrict tree)
if (assumption == NULL)
NEW_ERROR(tree, includes_ptr, ERROR, "assumption outside assumption clause");
return 0;
- pfail:
+ fail:
return -1;
}
@@ -433,7 +433,7 @@ static int validate_information_data(mds_kbdc_tree_t* restrict tree)
if (information == NULL)
NEW_ERROR(tree, includes_ptr, ERROR, "information outside information clause");
return 0;
- pfail:
+ fail:
return -1;
}
diff --git a/src/mds-kkbd.c b/src/mds-kkbd.c
index 82b3d22..95b7f02 100644
--- a/src/mds-kkbd.c
+++ b/src/mds-kkbd.c
@@ -250,7 +250,7 @@ int initialise_server(void)
return 0;
- pfail:
+ fail:
xperror(*argv);
if (stage < 5)
{
@@ -386,7 +386,7 @@ int unmarshal_server(char* state_buf)
fail_if (mds_message_unmarshal(&received, state_buf));
return 0;
- pfail:
+ fail:
xperror(*argv);
mds_message_destroy(&received);
free(mapping);
@@ -456,7 +456,7 @@ int master_loop(void)
fail_if ((errno = pthread_join(kbd_thread, &kbd_ret)));
rc = kbd_ret == NULL ? 0 : 1;
goto done;
- pfail:
+ fail:
xperror(*argv);
done:
pthread_mutex_destroy(&send_mutex);
@@ -490,7 +490,7 @@ void* keyboard_loop(void* data)
return NULL;
- pfail:
+ fail:
xperror(*argv);
raise(SIGTERM);
return (void*)1024;
diff --git a/src/mds-registry/mds-registry.c b/src/mds-registry/mds-registry.c
index 9751ff4..44cbe86 100644
--- a/src/mds-registry/mds-registry.c
+++ b/src/mds-registry/mds-registry.c
@@ -66,7 +66,7 @@ int preinitialise_server(void)
return 0;
- pfail:
+ fail:
xperror(*argv);
if (stage >= 1) pthread_mutex_destroy(&slave_mutex);
if (stage >= 2) pthread_cond_destroy(&slave_cond);
@@ -117,7 +117,7 @@ int initialise_server(void)
fail_if (mds_message_initialise(&received));
return 0;
- pfail:
+ fail:
xperror(*argv);
mds_message_destroy(&received);
return 1;
@@ -188,7 +188,7 @@ int master_loop(void)
rc = 0;
goto done;
- pfail:
+ fail:
xperror(*argv);
done:
/* Join with all slaves threads. */
diff --git a/src/mds-registry/reexec.c b/src/mds-registry/reexec.c
index 6b36cc8..6f6510e 100644
--- a/src/mds-registry/reexec.c
+++ b/src/mds-registry/reexec.c
@@ -197,7 +197,7 @@ int unmarshal_server(char* state_buf)
}
return 0;
- pfail:
+ fail:
xperror(*argv);
mds_message_destroy(&received);
if (stage >= 1)
diff --git a/src/mds-registry/registry.c b/src/mds-registry/registry.c
index 918b137..5f241ea 100644
--- a/src/mds-registry/registry.c
+++ b/src/mds-registry/registry.c
@@ -107,7 +107,7 @@ static int handle_close_message(void)
free(keys);
return 0;
- pfail:
+ fail:
xperror(*argv);
free(keys);
return -1;
@@ -167,7 +167,7 @@ static int registry_action_add(int has_key, char* command, size_t command_key, u
fail_if (advance_slaves(command));
return 0;
- pfail:
+ fail:
xperror(*argv);
return -1;
}
@@ -239,7 +239,7 @@ static int registry_action_act(char* command, int action, uint64_t client, hash_
}
return 0;
- pfail:
+ fail:
xperror(*argv);
hash_table_destroy(wait_set, (free_func*)reg_table_free_key, NULL);
free(wait_set);
diff --git a/src/mds-registry/slave.c b/src/mds-registry/slave.c
index 54774e2..8a4d221 100644
--- a/src/mds-registry/slave.c
+++ b/src/mds-registry/slave.c
@@ -114,7 +114,7 @@ static void* slave_loop(void* data)
goto done;
- pfail:
+ fail:
xperror(*argv);
done:
with_mutex (slave_mutex,
@@ -198,7 +198,7 @@ int start_slave(hash_table_t* restrict wait_set, const char* restrict recv_clien
pthread_mutex_unlock(&slave_mutex);
return 0;
- pfail:
+ fail:
xperror(*argv);
if (locked)
pthread_mutex_unlock(&slave_mutex);
@@ -284,7 +284,7 @@ slave_t* slave_create(hash_table_t* restrict wait_set, const char* restrict recv
return rc;
- pfail:
+ fail:
saved_errno = errno;
slave_destroy(rc), free(rc);
return errno = saved_errno, NULL;
diff --git a/src/mds-respawn.c b/src/mds-respawn.c
index 3e3406a..b95f40e 100644
--- a/src/mds-respawn.c
+++ b/src/mds-respawn.c
@@ -157,7 +157,7 @@ int parse_cmdline(void)
return 0;
- pfail:
+ fail:
xperror(*argv);
return 1;
}
@@ -243,7 +243,7 @@ int preinitialise_server(void)
fail_if (xsigaction(SIGUSR2, received_revive) < 0);
return 0;
- pfail:
+ fail:
xperror(*argv);
return 1;
}
@@ -302,7 +302,7 @@ int postinitialise_server(void)
spawn_server(i);
return 0;
- pfail:
+ fail:
xperror(*argv);
return 1;
}
diff --git a/src/mds-server/client.c b/src/mds-server/client.c
index 37ba906..4f5f997 100644
--- a/src/mds-server/client.c
+++ b/src/mds-server/client.c
@@ -262,7 +262,7 @@ size_t client_unmarshal(client_t* restrict this, char* restrict data)
rc += n * sizeof(char);
return rc;
- pfail:
+ fail:
saved_errno = errno;
mds_message_destroy(&(this->message));
for (i = 0; i < this->interception_conditions_count; i++)
diff --git a/src/mds-server/mds-server.c b/src/mds-server/mds-server.c
index abfc871..8ef44cc 100644
--- a/src/mds-server/mds-server.c
+++ b/src/mds-server/mds-server.c
@@ -148,7 +148,7 @@ int preinitialise_server(void)
return 0;
- pfail:
+ fail:
xperror(*argv);
return 1;
}
@@ -348,7 +348,7 @@ void* slave_loop(void* data)
return NULL;
- pfail:
+ fail:
xperror(*argv);
goto done;
@@ -483,7 +483,7 @@ void queue_message_multicast(char* message, size_t length, client_t* sender)
multicast->message_prefix = n;
message = NULL;
-#define pfail fail_in_mutex
+#define fail fail_in_mutex
/* Queue message multicasting. */
with_mutex (sender->mutex,
new_buf = sender->multicasts;
@@ -496,7 +496,7 @@ void queue_message_multicast(char* message, size_t length, client_t* sender)
fail_in_mutex:
xperror(*argv);
);
-#undef pfail
+#undef fail
done:
/* Release resources. */
@@ -509,7 +509,7 @@ void queue_message_multicast(char* message, size_t length, client_t* sender)
free(multicast);
return;
- pfail:
+ fail:
xperror(*argv);
goto done;
}
diff --git a/src/mds-server/receiving.c b/src/mds-server/receiving.c
index 100d717..71f1210 100644
--- a/src/mds-server/receiving.c
+++ b/src/mds-server/receiving.c
@@ -93,7 +93,7 @@ static int modifying_notify(client_t* client, mds_message_t message, uint64_t mo
return 0;
- pfail:
+ fail:
xperror(*argv);
if (multicast != NULL)
{
@@ -205,7 +205,7 @@ static int assign_and_send_id(client_t* client, const char* message_id)
/* Queue message to be sent when this function returns.
This done to simplify `multicast_message` for re-exec and termination. */
-#define pfail fail_in_mutex
+#define fail fail_in_mutex
with_mutex (client->mutex,
if (client->send_pending_size == 0)
{
@@ -226,9 +226,9 @@ static int assign_and_send_id(client_t* client, const char* message_id)
(msgbuf = NULL, rc = 0, errno = 0);
fail_in_mutex:
);
-#undef pfail
+#undef fail
- pfail: /* Also success. */
+ fail: /* Also success. */
xperror(*argv);
free(msgbuf);
return rc;
@@ -329,7 +329,7 @@ int message_received(client_t* client)
return 0;
- pfail:
+ fail:
xperror(*argv);
free(msgbuf);
return 0;
diff --git a/src/mds-server/slavery.c b/src/mds-server/slavery.c
index a951f99..7ff801d 100644
--- a/src/mds-server/slavery.c
+++ b/src/mds-server/slavery.c
@@ -130,7 +130,7 @@ client_t* initialise_client(int client_fd)
return information;
- pfail:
+ fail:
saved_errno = errno;
if (locked)
pthread_mutex_unlock(&slave_mutex);
@@ -139,6 +139,6 @@ client_t* initialise_client(int client_fd)
{
with_mutex (slave_mutex, linked_list_remove(&client_list, entry););
}
- return saved_errno = errno, NULL;
+ return errno = saved_errno, NULL;
}
diff --git a/src/mds-vt.c b/src/mds-vt.c
index b268647..1cc377e 100644
--- a/src/mds-vt.c
+++ b/src/mds-vt.c
@@ -277,7 +277,7 @@ int initialise_server(void)
no_display:
eprint("no display has been set, how did this happen.");
return 1;
- pfail:
+ fail:
xperror(*argv);
unlink(vtfile_path);
if (display_tty_fd >= 0)
@@ -451,7 +451,7 @@ int master_loop(void)
xperror(*argv);
vt_close(display_tty_fd, &old_vt_stat);
goto done;
- pfail:
+ fail:
xperror(*argv);
done:
rc |= secondary_thread_failed;
@@ -503,7 +503,7 @@ void* secondary_loop(void* data)
}
goto done;
- pfail:
+ fail:
xperror(*argv);
secondary_thread_failed = 1;
done:
diff --git a/src/mds.c b/src/mds.c
index 1c0f002..bad0060 100644
--- a/src/mds.c
+++ b/src/mds.c
@@ -217,7 +217,7 @@ int main(int argc_, char** argv_)
return rc;
- pfail:
+ fail:
xperror(*argv);
rc = 1;
goto done;
@@ -412,7 +412,7 @@ int spawn_and_respawn_server(int fd)
_exit(1);
return rc;
- pfail:
+ fail:
xperror(*argv);
goto done;
}
@@ -452,7 +452,7 @@ int create_directory_root(const char* pathname)
return 0;
- pfail:
+ fail:
xperror(*argv);
return 1;
}
@@ -544,7 +544,7 @@ int unlink_recursive(const char* pathname)
return rc;
- pfail:
+ fail:
xperror(*argv);
rc = -1;
goto done;
diff --git a/src/libmdsserver/macros.h b/src/libmdsserver/macros.h
index 84b6060..fc47e0a 100644
--- a/src/libmdsserver/macros.h
+++ b/src/libmdsserver/macros.h
@@ -379,13 +379,13 @@
/**
* Go to the label `pfail` if a condition is met
*
* @param ... The condition
*/
#define fail_if(...) \
if (__VA_ARGS__) \
- do { fprintf(stderr, "failure at %s:%i\n", __FILE__, __LINE__); goto pfail; } while (0)
+ do { fprintf(stderr, "failure at %s:%i\n", __FILE__, __LINE__); goto fail; } while (0)
/**
@@ -379,13 +379,13 @@
/**
- * Go to the label `pfail` if a condition is met
+ * Go to the label `fail` if a condition is met
*
* @param ... The condition